@@ -6,6 +6,8 @@ switchboard.tests.test_models
 :license: Apache License 2.0, see LICENSE for more details.
 """
 
+from datetime import datetime
+
 from nose.tools import assert_equals, assert_true, assert_false
 from mock import Mock
 
@@ -21,25 +23,25 @@ class TestVersioningMongoModel(object):
         VersioningMongoModel._versioned_collection().drop()
 
     def test_diff_fields_added(self):
-        self.m.previous_version = lambda: dict(a=1, b=2)
+        self.m.previous_version = lambda: VersioningMongoModel(a=1, b=2)
         self.m.c.find_one = lambda x: dict(a=1, b=2, c=3)
         delta = self.m._diff()
         assert_equals(delta['added'], dict(c=3))
 
     def test_diff_fields_deleted(self):
-        self.m.previous_version = lambda: dict(a=1, b=2)
+        self.m.previous_version = lambda: VersioningMongoModel(a=1, b=2)
         self.m.c.find_one = lambda x: dict(a=1)
         delta = self.m._diff()
         assert_equals(delta['deleted'], dict(b=2))
 
     def test_diff_fields_changed(self):
-        self.m.previous_version = lambda: dict(a=1, b=2)
+        self.m.previous_version = lambda: VersioningMongoModel(a=1, b=2)
         self.m.c.find_one = lambda x: dict(a=1, b=3)
         delta = self.m._diff()
         assert_equals(delta['changed'], dict(b=(2, 3)))
 
     def test_diff_fields_same(self):
-        self.m.previous_version = lambda: dict(a=1, b=2)
+        self.m.previous_version = lambda: VersioningMongoModel(a=1, b=2)
         self.m.c.find_one = lambda x: dict(a=1, b=2)
         delta = self.m._diff()
         assert_equals(delta['changed'], dict())
@@ -55,7 +57,7 @@ class TestVersioningMongoModel(object):
         assert_equals(delta['deleted'], dict())
 
     def test_diff_removed(self):
-        self.m.previous_version = lambda: dict(a=1, b=2)
+        self.m.previous_version = lambda: VersioningMongoModel(a=1, b=2)
         self.m.c.find_one = lambda x: None
         delta = self.m._diff()
         assert_equals(delta['changed'], dict())
@@ -66,46 +68,51 @@ class TestVersioningMongoModel(object):
         self.m.previous_version = lambda: None
         self.m.c.find_one = lambda x: None
         delta = self.m._diff()
-        assert_equals(delta, None)
+        assert_equals(delta, dict(added={}, deleted={}, changed={}))
 
     def test_previous_version_new(self):
         c = Mock()
         c.find.return_value = None
         self.m._versioned_collection = lambda: c
         prev = self.m.previous_version()
-        assert_false(prev._id)
+        assert_false(hasattr(prev, '_id'))
 
     def test_previous_version_singlediff(self):
         delta = dict(
             added=dict(a=1, b=2)
         )
         c = Mock()
-        c.find.return_value = [dict(delta=delta)]
+        c.find.return_value = [dict(timestamp=datetime.utcnow(),
+                                    delta=delta)]
         self.m._versioned_collection = lambda: c
         prev = self.m.previous_version()
         assert_equals(prev.a, 1)
         assert_equals(prev.b, 2)
 
     def test_previous_version_multidiff(self):
-        v1 = dict(delta=dict(
-            added=dict(a=1, b=2)
-        ))
-        v2 = dict(delta=dict(
-            changed=dict(b=(2, 3))
-        ))
-        v3 = dict(delta=dict(
-            added=dict(c=4)
-        ))
-        v4 = dict(delta=dict(
-            deleted=dict(a=1)
-        ))
+        v1 = dict(
+            timestamp=datetime.utcnow(),
+            delta=dict(added=dict(a=1, b=2))
+        )
+        v2 = dict(
+            timestamp=datetime.utcnow(),
+            delta=dict(changed=dict(b=(2, 3)))
+        )
+        v3 = dict(
+            timestamp=datetime.utcnow(),
+            delta=dict(added=dict(c=4))
+        )
+        v4 = dict(
+            timestamp=datetime.utcnow(),
+            delta=dict(deleted=dict(a=1))
+        )
         c = Mock()
         c.find.return_value = [v1, v2, v3, v4]
         self.m._versioned_collection = lambda: c
         prev = self.m.previous_version()
         assert_equals(prev.b, 3)
         assert_equals(prev.c, 4)
-        assert_false(hasattr(prev.a))
+        assert_false(hasattr(prev, 'a'))
 
 
 class TestConstant(object):
@@ -136,8 +143,6 @@ class TestConstant(object):
 class TestSwitch(object):
     def setup(self):
         self.switch = Switch.create(key='test')
-        # clear out the initial version
-        Switch._versioned_collection().drop()
 
     def teardown(self):
         Switch.c.drop()
@@ -149,6 +154,10 @@ class TestSwitch(object):
         _id = self.switch._id
         assert_equals(self.switch.to_bson(),
                       self.switch.c.find_one(dict(_id=_id)))
-        version = self.switch._versioned_collection().find_one(dict(_id=_id))
+        vc = self.switch._versioned_collection()
+        versions = list(vc.find(dict(switch_id=_id)))
+        assert_true(versions)
+        versions.sort(key=lambda x:x['timestamp'])
+        version = versions[-1]
         assert_true(version)
         assert_equals(version['delta']['changed']['key'], ('test', 'test2'))
